import { Card } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { Switch } from '@/components/ui/switch';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@/components/ui/select';
import { Slider } from '@/components/ui/slider';
import { Sidebar } from '@/components/Sidebar';
import { Settings as SettingsIcon, Bell, DollarSign, Shield, Target } from 'lucide-react';
import { useState } from 'react';

export default function Settings() {
  const [notifications, setNotifications] = useState(true);
  const [autoTrade, setAutoTrade] = useState(false);
  const [riskLevel, setRiskLevel] = useState([2]);
  const [martingaleEnabled, setMartingaleEnabled] = useState(false);

  return (
    <div className="flex h-screen overflow-hidden bg-trading-dark text-white">
      <Sidebar />
      <div className="flex-1 p-6 overflow-auto">
        <div className="mb-6">
          <h1 className="text-3xl font-bold mb-2">Settings</h1>
          <p className="text-trading-muted">Configure your trading preferences and risk management</p>
        </div>

        <div className="grid grid-cols-12 gap-6">
          {/* Trading Settings */}
          <div className="col-span-6">
            <Card className="bg-trading-gray p-6">
              <div className="flex items-center space-x-2 mb-4">
                <Target className="w-5 h-5" />
                <h3 className="text-lg font-semibold">Trading Settings</h3>
              </div>
              
              <div className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="confidence">Minimum Signal Confidence</Label>
                  <Select defaultValue="85">
                    <SelectTrigger className="bg-trading-light border-trading-slate">
                      <SelectValue />
                    </SelectTrigger>
                    <SelectContent className="bg-trading-light border-trading-slate">
                      <SelectItem value="80">80%</SelectItem>
                      <SelectItem value="85">85%</SelectItem>
                      <SelectItem value="90">90%</SelectItem>
                      <SelectItem value="95">95%</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div className="space-y-2">
                  <Label htmlFor="expiry">Default Expiry Time</Label>
                  <Select defaultValue="1m">
                    <SelectTrigger className="bg-trading-light border-trading-slate">
                      <SelectValue />
                    </SelectTrigger>
                    <SelectContent className="bg-trading-light border-trading-slate">
                      <SelectItem value="30s">30 Seconds</SelectItem>
                      <SelectItem value="1m">1 Minute</SelectItem>
                      <SelectItem value="2m">2 Minutes</SelectItem>
                      <SelectItem value="5m">5 Minutes</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div className="space-y-2">
                  <Label>Risk Level: {riskLevel[0]}% per trade</Label>
                  <Slider
                    value={riskLevel}
                    onValueChange={setRiskLevel}
                    max={10}
                    min={1}
                    step={0.5}
                    className="w-full"
                  />
                  <div className="flex justify-between text-xs text-trading-muted">
                    <span>Conservative (1%)</span>
                    <span>Aggressive (10%)</span>
                  </div>
                </div>

                <div className="flex items-center justify-between">
                  <div className="space-y-0.5">
                    <Label>Auto Trading</Label>
                    <div className="text-sm text-trading-muted">
                      Automatically execute high-confidence signals
                    </div>
                  </div>
                  <Switch
                    checked={autoTrade}
                    onCheckedChange={setAutoTrade}
                  />
                </div>
              </div>
            </Card>
          </div>

          {/* Risk Management */}
          <div className="col-span-6">
            <Card className="bg-trading-gray p-6">
              <div className="flex items-center space-x-2 mb-4">
                <Shield className="w-5 h-5" />
                <h3 className="text-lg font-semibold">Risk Management</h3>
              </div>
              
              <div className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="daily-limit">Daily Loss Limit</Label>
                  <Input
                    id="daily-limit"
                    type="number"
                    placeholder="100"
                    className="bg-trading-light border-trading-slate"
                  />
                </div>

                <div className="space-y-2">
                  <Label htmlFor="daily-target">Daily Profit Target</Label>
                  <Input
                    id="daily-target"
                    type="number"
                    placeholder="200"
                    className="bg-trading-light border-trading-slate"
                  />
                </div>

                <div className="space-y-2">
                  <Label htmlFor="max-consecutive">Max Consecutive Losses</Label>
                  <Select defaultValue="3">
                    <SelectTrigger className="bg-trading-light border-trading-slate">
                      <SelectValue />
                    </SelectTrigger>
                    <SelectContent className="bg-trading-light border-trading-slate">
                      <SelectItem value="2">2 Losses</SelectItem>
                      <SelectItem value="3">3 Losses</SelectItem>
                      <SelectItem value="4">4 Losses</SelectItem>
                      <SelectItem value="5">5 Losses</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div className="flex items-center justify-between">
                  <div className="space-y-0.5">
                    <Label>Martingale Strategy</Label>
                    <div className="text-sm text-trading-muted">
                      Double stake after losses (risky)
                    </div>
                  </div>
                  <Switch
                    checked={martingaleEnabled}
                    onCheckedChange={setMartingaleEnabled}
                  />
                </div>
              </div>
            </Card>
          </div>

          {/* Notifications */}
          <div className="col-span-6">
            <Card className="bg-trading-gray p-6">
              <div className="flex items-center space-x-2 mb-4">
                <Bell className="w-5 h-5" />
                <h3 className="text-lg font-semibold">Notifications</h3>
              </div>
              
              <div className="space-y-4">
                <div className="flex items-center justify-between">
                  <div className="space-y-0.5">
                    <Label>Signal Alerts</Label>
                    <div className="text-sm text-trading-muted">
                      Get notified of new high-confidence signals
                    </div>
                  </div>
                  <Switch
                    checked={notifications}
                    onCheckedChange={setNotifications}
                  />
                </div>

                <div className="flex items-center justify-between">
                  <div className="space-y-0.5">
                    <Label>Trade Results</Label>
                    <div className="text-sm text-trading-muted">
                      Notify when trades win or lose
                    </div>
                  </div>
                  <Switch defaultChecked />
                </div>

                <div className="flex items-center justify-between">
                  <div className="space-y-0.5">
                    <Label>Market Events</Label>
                    <div className="text-sm text-trading-muted">
                      News and market opening/closing alerts
                    </div>
                  </div>
                  <Switch defaultChecked />
                </div>
              </div>
            </Card>
          </div>

          {/* Account Settings */}
          <div className="col-span-6">
            <Card className="bg-trading-gray p-6">
              <div className="flex items-center space-x-2 mb-4">
                <DollarSign className="w-5 h-5" />
                <h3 className="text-lg font-semibold">Account Settings</h3>
              </div>
              
              <div className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="balance">Account Balance</Label>
                  <Input
                    id="balance"
                    type="number"
                    placeholder="1000"
                    className="bg-trading-light border-trading-slate"
                  />
                </div>

                <div className="space-y-2">
                  <Label htmlFor="currency">Account Currency</Label>
                  <Select defaultValue="usd">
                    <SelectTrigger className="bg-trading-light border-trading-slate">
                      <SelectValue />
                    </SelectTrigger>
                    <SelectContent className="bg-trading-light border-trading-slate">
                      <SelectItem value="usd">USD ($)</SelectItem>
                      <SelectItem value="eur">EUR (€)</SelectItem>
                      <SelectItem value="gbp">GBP (£)</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div className="space-y-2">
                  <Label htmlFor="timezone">Timezone</Label>
                  <Select defaultValue="utc">
                    <SelectTrigger className="bg-trading-light border-trading-slate">
                      <SelectValue />
                    </SelectTrigger>
                    <SelectContent className="bg-trading-light border-trading-slate">
                      <SelectItem value="utc">UTC</SelectItem>
                      <SelectItem value="est">Eastern (EST)</SelectItem>
                      <SelectItem value="gmt">London (GMT)</SelectItem>
                      <SelectItem value="cet">Central Europe (CET)</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
              </div>
            </Card>
          </div>
        </div>

        {/* Save Button */}
        <div className="mt-6 flex justify-end">
          <Button className="bg-trading-success hover:bg-trading-success/80 text-trading-dark font-semibold px-8">
            Save Settings
          </Button>
        </div>
      </div>
    </div>
  );
}