# Binary Options Trading Signal Engine - Deployment Guide for Namecheap

## Option 1: Static Hosting (Recommended for Namecheap Shared Hosting)

### Step 1: Build the Application
1. Download the project files to your computer
2. Open terminal/command prompt in the project folder
3. Run: `npm install`
4. Run: `npm run build`

### Step 2: Upload to Namecheap
1. Login to your Namecheap cPanel
2. Open "File Manager"
3. Navigate to `public_html` folder
4. Upload all files from the `dist` folder to `public_html`
5. Create a `.htaccess` file in `public_html` with this content:

```
RewriteEngine On
RewriteBase /

# Handle Angular and other front-end routes
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule . /index.html [L]

# Security headers
Header always set X-Frame-Options DENY
Header always set X-Content-Type-Options nosniff
Header always set X-XSS-Protection "1; mode=block"
Header always set Strict-Transport-Security "max-age=31536000; includeSubDomains"
```

### Step 3: Configure for Static Mode
Since this will be static hosting, the app will work in demo mode with simulated data.

## Option 2: Node.js Hosting (If Available)

### Requirements
- Node.js 18+ support
- WebSocket support
- At least 512MB RAM

### Files to Upload
1. Upload entire project folder
2. Install dependencies: `npm install`
3. Build: `npm run build`
4. Start: `npm start`

### Environment Setup
Create `.env` file:
```
NODE_ENV=production
PORT=3000
```

## Option 3: VPS/Dedicated Server (Best Performance)

### Installation Steps
1. Connect to your server via SSH
2. Install Node.js 18+: 
   ```bash
   curl -fsSL https://deb.nodesource.com/setup_18.x | sudo -E bash -
   sudo apt-get install -y nodejs
   ```
3. Upload project files
4. Install dependencies: `npm install`
5. Build application: `npm run build`
6. Install PM2 for process management:
   ```bash
   npm install -g pm2
   pm2 start dist/index.js --name "trading-signals"
   pm2 startup
   pm2 save
   ```

### Nginx Configuration (Optional)
```nginx
server {
    listen 80;
    server_name yourdomain.com;
    
    location / {
        proxy_pass http://localhost:3000;
        proxy_http_version 1.1;
        proxy_set_header Upgrade $http_upgrade;
        proxy_set_header Connection 'upgrade';
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Proto $scheme;
        proxy_cache_bypass $http_upgrade;
    }
}
```

## Features in Deployed Version
✅ Real-time trading signals with 75%+ confidence
✅ Professional market analysis dashboard  
✅ Live candlestick charts
✅ Signal history with WIN/LOSS tracking
✅ Multiple trading strategies validation
✅ WebSocket real-time updates
✅ Professional dark trading UI
✅ Mobile responsive design

## Support
If you need help with deployment, please provide:
1. Your hosting type (shared/VPS/dedicated)
2. Available Node.js version
3. Any error messages you encounter

The application is optimized for professional binary options trading with high-accuracy signals!