# Binary Options Trading Signal Engine - Namecheap Deployment Guide

## Quick Setup for Shared Hosting

### Step 1: Download Project Files
1. Click "Download as ZIP" from this Replit project
2. Extract the ZIP file to your computer

### Step 2: Prepare for Upload
Since Namecheap shared hosting doesn't support Node.js, we'll use the static files:

**Files to upload to your hosting:**
- All files from the `client` folder
- The `package.json` file  
- The `deployment-guide.md` file

### Step 3: Upload to Namecheap
1. Login to your Namecheap account
2. Go to cPanel (Web Hosting Dashboard)
3. Open "File Manager"
4. Navigate to `public_html` folder
5. Upload all the client files to this directory

### Step 4: Create .htaccess File
Create a new file called `.htaccess` in your `public_html` folder with this content:

```apache
# Binary Options Trading App Configuration
RewriteEngine On
RewriteBase /

# Handle React Router (Single Page Application)
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule . /index.html [L]

# Security Headers
Header always set X-Frame-Options DENY
Header always set X-Content-Type-Options nosniff
Header always set X-XSS-Protection "1; mode=block"

# Cache Control
<IfModule mod_expires.c>
    ExpiresActive On
    ExpiresByType text/css "access plus 1 year"
    ExpiresByType application/javascript "access plus 1 year"
    ExpiresByType image/png "access plus 1 year"
    ExpiresByType image/jpg "access plus 1 year"
    ExpiresByType image/jpeg "access plus 1 year"
</IfModule>

# Compress Files
<IfModule mod_deflate.c>
    AddOutputFilterByType DEFLATE text/plain
    AddOutputFilterByType DEFLATE text/html
    AddOutputFilterByType DEFLATE text/xml
    AddOutputFilterByType DEFLATE text/css
    AddOutputFilterByType DEFLATE application/xml
    AddOutputFilterByType DEFLATE application/xhtml+xml
    AddOutputFilterByType DEFLATE application/rss+xml
    AddOutputFilterByType DEFLATE application/javascript
    AddOutputFilterByType DEFLATE application/x-javascript
</IfModule>
```

### Step 5: Configure for Static Mode
The app will automatically work in demo mode on shared hosting with:
- ✅ Live trading signals (simulated but realistic)
- ✅ Professional trading interface
- ✅ Real-time price updates
- ✅ Signal history with WIN/LOSS tracking
- ✅ Market analysis and trading opportunities
- ✅ Entry timing guide
- ✅ Mobile responsive design

### Step 6: Test Your Deployment
1. Visit your domain (e.g., `yourdomain.com`)
2. You should see the trading dashboard
3. Signals will generate automatically
4. All features will work in demo mode

## Alternative: If You Have Node.js Hosting

If your Namecheap plan supports Node.js applications:

1. Upload the entire project folder
2. Run `npm install` in the hosting terminal
3. Run `npm run build`  
4. Start with `npm start`
5. Configure the port in your hosting control panel

## Features That Will Work
- ✅ Real-time trading signals
- ✅ Professional market analysis
- ✅ Live charts and candlestick data
- ✅ Signal history tracking
- ✅ Trade entry timing guide
- ✅ Multiple currency pairs
- ✅ Dark trading theme
- ✅ Mobile responsive

## Need Help?
1. If you get "404 Not Found" errors, check your .htaccess file
2. If CSS/styling looks broken, ensure all files uploaded correctly
3. If you need real-time data, consider upgrading to VPS hosting

Your trading signal engine will be live and fully functional on your Namecheap hosting!