import { Card } from '@/components/ui/card';
import { BarChart3, Activity, History, Settings, Wifi, WifiOff } from 'lucide-react';
import { formatTime } from '@/lib/utils';
import { useMarketStatus, useTimeUpdates } from '@/hooks/useWebSocket';
import { useLocation } from 'wouter';

export function Sidebar() {
  const [location] = useLocation();
  const { status: marketStatus, isConnected } = useMarketStatus();
  const currentTime = useTimeUpdates();

  const getStatusColor = () => {
    if (!isConnected) return 'bg-trading-danger';
    if (marketStatus === 'ACTIVE') return 'bg-trading-success pulse-green';
    return 'bg-trading-warning';
  };

  const getStatusText = () => {
    if (!isConnected) return 'DISCONNECTED';
    return marketStatus;
  };

  const navItems = [
    { path: '/', label: 'Dashboard', icon: Activity },
    { path: '/live-charts', label: 'Live Charts', icon: BarChart3 },
    { path: '/signal-history', label: 'Signal History', icon: History },
    { path: '/settings', label: 'Settings', icon: Settings },
  ];

  return (
    <div className="w-64 bg-trading-gray border-r border-trading-light flex-shrink-0">
      <div className="p-6">
        <div className="flex items-center space-x-3 mb-8">
          <div className="w-10 h-10 bg-trading-warning rounded-lg flex items-center justify-center">
            <BarChart3 className="text-trading-dark text-xl" />
          </div>
          <div>
            <h1 className="text-xl font-bold">Quotex Engine</h1>
            <p className="text-trading-muted text-sm">Signal Pro v2.1</p>
          </div>
        </div>
        
        {/* Navigation Menu */}
        <nav className="space-y-2">
          {navItems.map(({ path, label, icon: Icon }) => (
            <a
              key={path}
              href={path}
              className={`flex items-center space-x-3 px-4 py-3 rounded-lg transition ${
                location === path
                  ? 'bg-trading-light text-trading-warning'
                  : 'hover:bg-trading-light text-trading-muted hover:text-white'
              }`}
            >
              <Icon className="w-5 h-5" />
              <span>{label}</span>
            </a>
          ))}
        </nav>
        
        {/* Market Status */}
        <Card className="mt-8 p-4 bg-trading-light border-trading-slate">
          <div className="flex items-center justify-between mb-2">
            <span className="text-sm text-trading-muted">Market Status</span>
            <div className={`w-2 h-2 rounded-full ${getStatusColor()}`}></div>
          </div>
          <div className="text-sm font-semibold text-trading-success">{getStatusText()}</div>
          <div className="text-xs text-trading-muted mt-1 flex items-center">
            {isConnected ? (
              <Wifi className="w-3 h-3 mr-1" />
            ) : (
              <WifiOff className="w-3 h-3 mr-1" />
            )}
            {formatTime(currentTime)}
          </div>
        </Card>
      </div>
    </div>
  );
}