import { Card } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Activity, TrendingUp, TrendingDown, Minus } from 'lucide-react';
import { getIndicatorStatusColor } from '@/lib/utils';
import { useQuery } from '@tanstack/react-query';
import type { TechnicalIndicator } from '@shared/schema';

interface TechnicalIndicatorsProps {
  selectedPair: string;
}

export function TechnicalIndicators({ selectedPair }: TechnicalIndicatorsProps) {
  const { data: indicators, isLoading } = useQuery({
    queryKey: ['/api/technical-indicators', selectedPair],
    refetchInterval: 5000, // Refresh every 5 seconds
  });

  const getSignalIcon = (signal: 'BULLISH' | 'BEARISH' | 'NEUTRAL') => {
    switch (signal) {
      case 'BULLISH':
        return <TrendingUp className="w-3 h-3" />;
      case 'BEARISH':
        return <TrendingDown className="w-3 h-3" />;
      case 'NEUTRAL':
        return <Minus className="w-3 h-3" />;
    }
  };

  const getSignalColor = (signal: 'BULLISH' | 'BEARISH' | 'NEUTRAL') => {
    switch (signal) {
      case 'BULLISH':
        return 'text-trading-success';
      case 'BEARISH':
        return 'text-trading-danger';
      case 'NEUTRAL':
        return 'text-trading-muted';
    }
  };

  if (isLoading) {
    return (
      <div className="grid grid-cols-4 gap-4">
        {[...Array(4)].map((_, i) => (
          <Card key={i} className="bg-trading-gray rounded-lg p-4 animate-pulse">
            <div className="h-4 bg-trading-slate rounded mb-2"></div>
            <div className="h-6 bg-trading-slate rounded mb-1"></div>
            <div className="h-3 bg-trading-slate rounded"></div>
          </Card>
        ))}
      </div>
    );
  }

  return (
    <div className="grid grid-cols-4 gap-4">
      {indicators?.map((indicator, index) => (
        <Card key={index} className="bg-trading-gray rounded-lg p-4">
          <div className="flex items-center justify-between mb-2">
            <span className="text-sm text-trading-muted">{indicator.name}</span>
            <div className={`w-2 h-2 rounded-full ${getIndicatorStatusColor(indicator.status)}`}></div>
          </div>
          
          <div className={`font-mono text-lg font-semibold ${getSignalColor(indicator.signal)}`}>
            <div className="flex items-center space-x-1">
              {getSignalIcon(indicator.signal)}
              <span>{indicator.value}</span>
            </div>
          </div>
          
          <div className="text-xs text-trading-muted mt-1">
            {indicator.signal === 'BULLISH' && 'Bullish signal'}
            {indicator.signal === 'BEARISH' && 'Bearish signal'}
            {indicator.signal === 'NEUTRAL' && 'Neutral'}
          </div>
        </Card>
      )) || (
        <div className="col-span-4 text-center text-trading-muted py-4">
          <Activity className="w-8 h-8 mx-auto mb-2 opacity-50" />
          <p>Loading technical indicators...</p>
        </div>
      )}
    </div>
  );
}
