import { useState } from 'react';
import { SimpleChart } from '@/components/SimpleChart';
import { TradingOpportunities } from '@/components/TradingOpportunities';
import { TradeEntryGuide } from '@/components/TradeEntryGuide';
import { Sidebar } from '@/components/Sidebar';
import { Card } from '@/components/ui/card';
import { formatPrice } from '@/lib/utils';
import { useQuery } from '@tanstack/react-query';

export default function LiveCharts() {
  const [selectedPair, setSelectedPair] = useState('EUR/USD');

  const { data: marketData } = useQuery({
    queryKey: ['/api/market-data'],
    refetchInterval: 5000,
  });

  const currentMarketData = marketData?.find((item: any) => item.pair === selectedPair);

  return (
    <div className="flex h-screen overflow-hidden bg-trading-dark text-white">
      <Sidebar />
      
      {/* Main Content */}
      <div className="flex-1 p-6 overflow-auto">
        <div className="mb-6">
          <h1 className="text-3xl font-bold mb-2">Live Charts</h1>
          <p className="text-trading-muted">Real-time candlestick charts and market data</p>
        </div>

        <div className="grid grid-cols-12 gap-6">
          {/* Left Panel - Market Data */}
          <div className="col-span-4 space-y-6">
            <TradeEntryGuide />
            
            {/* Quick Stats */}
            <Card className="bg-trading-gray p-6">
              <h3 className="text-lg font-semibold mb-4">Market Stats</h3>
              {currentMarketData ? (
                <div className="space-y-3">
                  <div className="flex justify-between">
                    <span className="text-trading-muted">Current Price</span>
                    <span className="font-mono font-semibold">
                      {formatPrice(currentMarketData.price, selectedPair)}
                    </span>
                  </div>
                  <div className="flex justify-between">
                    <span className="text-trading-muted">Change</span>
                    <span className={`font-mono font-semibold ${
                      currentMarketData.changePercent >= 0 ? 'text-trading-success' : 'text-trading-danger'
                    }`}>
                      {currentMarketData.changePercent >= 0 ? '+' : ''}{currentMarketData.changePercent.toFixed(2)}%
                    </span>
                  </div>
                  <div className="flex justify-between">
                    <span className="text-trading-muted">Volatility</span>
                    <span className="font-mono font-semibold text-trading-warning">
                      {Math.abs(currentMarketData.changePercent) > 0.1 ? 'High' : 'Normal'}
                    </span>
                  </div>
                </div>
              ) : (
                <div className="text-trading-muted">Loading market data...</div>
              )}
            </Card>
          </div>
          
          {/* Right Panel - Charts */}
          <div className="col-span-8 space-y-6">
            {/* Main Chart */}
            <SimpleChart 
              pair={selectedPair}
              onPairChange={setSelectedPair}
            />
            
            {/* Trading Opportunities */}
            <TradingOpportunities selectedPair={selectedPair} />
          </div>
        </div>
      </div>
    </div>
  );
}