import { Card } from '@/components/ui/card';
import { SignalHistory } from '@/components/SignalHistory';
import { Sidebar } from '@/components/Sidebar';
import { useQuery } from '@tanstack/react-query';
import type { StrategyPerformance } from '@shared/schema';
import { Progress } from '@/components/ui/progress';
import { Target, TrendingUp, TrendingDown, BarChart3 } from 'lucide-react';

export default function SignalHistoryPage() {
  const { data: strategyPerformance } = useQuery({
    queryKey: ['/api/strategy-performance'],
    refetchInterval: 60000,
  });

  return (
    <div className="flex h-screen overflow-hidden bg-trading-dark text-white">
      <Sidebar />
      
      <div className="flex-1 p-6 overflow-auto">
        <div className="mb-6">
          <h1 className="text-3xl font-bold mb-2">Signal History & Performance</h1>
          <p className="text-trading-muted">Track your trading signals and strategy performance</p>
        </div>

        <div className="grid grid-cols-12 gap-6">
          {/* Strategy Performance Cards */}
          <div className="col-span-12 grid grid-cols-4 gap-4 mb-6">
            {strategyPerformance?.map((strategy: StrategyPerformance) => (
              <Card key={strategy.name} className="bg-trading-gray p-6">
                <div className="flex items-center justify-between mb-4">
                  <h3 className="font-semibold">{strategy.name}</h3>
                  <BarChart3 className="w-5 h-5 text-trading-muted" />
                </div>
                
                <div className="space-y-3">
                  <div>
                    <div className="flex items-center justify-between mb-1">
                      <span className="text-sm text-trading-muted">Accuracy</span>
                      <span className="font-bold text-trading-success">{strategy.accuracy}%</span>
                    </div>
                    <Progress value={strategy.accuracy} className="h-2" />
                  </div>
                  
                  <div className="grid grid-cols-3 gap-2 text-sm">
                    <div className="text-center">
                      <div className="font-bold">{strategy.signals}</div>
                      <div className="text-trading-muted text-xs">Total</div>
                    </div>
                    <div className="text-center">
                      <div className="font-bold text-trading-success">{strategy.wins}</div>
                      <div className="text-trading-muted text-xs">Wins</div>
                    </div>
                    <div className="text-center">
                      <div className="font-bold text-trading-danger">{strategy.losses}</div>
                      <div className="text-trading-muted text-xs">Losses</div>
                    </div>
                  </div>
                </div>
              </Card>
            )) || (
              <div className="col-span-4 text-center text-trading-muted py-8">
                <Target className="w-12 h-12 mx-auto mb-2 opacity-50" />
                <p>Loading performance data...</p>
              </div>
            )}
          </div>

          {/* Signal History Table */}
          <div className="col-span-12">
            <SignalHistory />
          </div>
        </div>
      </div>
    </div>
  );
}